@@ -14,7 +14,7 @@ __all__ = [
     'readlines','writelines',
     'zip_files','unzip_file',
     'BB','bbfy','xywh2xyXY','df2bbs',
-    'Info','Warn','Debug','Excep',
+    'Info','Warn','Debug','Excep','reset_logger_width',
     'display', 'print'
 ]
 
